{% load widget_tweaks %}
    {% if field|widget_type == 'checkboxinput' or field|widget_type == 'radioselect'%}
        <label for="{{ field.auto_id }}" class="{% if field.field.required %}required{% endif %}">
            {% include "arctic/partials/form_field_parts/render_field.html" %}
            {% include "arctic/partials/form_field_parts/field_label.html" %}
        </label>
    {% else %}
        <label for="{{ field.auto_id }}" class="{% if field.field.required %}required{% endif %}">
            {% include "arctic/partials/form_field_parts/field_label.html" %}
        </label>
        {% include "arctic/partials/form_field_parts/checkbox_select_multiple.html" %}
    {% endif %}
