{% load i18n %}


{% if form.is_bound and not form.is_valid %}
    <div class="row">
        <div class="column">
        <div class="callout alert" data-closable>
            {% trans "Oops! We found some errors. Please check the error messages below and try again." %}
            <button class="close-button" aria-label="Dismiss alert" type="button" data-close>
                <span aria-hidden="true">&times;</span>
            </button>
        </div>
        </div>
    </div>
{% endif %}


{% if form.non_field_errors %}
    {% for error in form.non_field_errors %}
        {# todo #}
        <p>{{ error }}</p>
    {% endfor %}
{% endif %}