{% load arctic_tags %}
{% load i18n %}

{% if paginator.num_pages > 1 %}
    <div class="row align-middle align-justify">
        <ul class="pagination column" role="navigation" aria-label="Pagination">
            {% if page_obj.has_previous %}
                <li>
                    <a href="?{% get_parameters page %}page={{ page_obj.previous_page_number }}" aria-label="Previous page">
                        {% trans "Previous page" %}
                    </a>
                </li>
            {% else %}
                <li class="disabled">
                    {% trans "Previous page" %}
                </li>
            {% endif %}

            {% if page_obj.has_next %}
                <li>
                    <a href="?{% get_parameters page %}page={{ page_obj.next_page_number }}" aria-label="Next page">
                        {% trans "Next page" %}
                    </a>
                </li>
            {% else %}
                <li class="disabled">
                    {% trans "Next page" %}
                </li>
            {% endif %}

        </ul>

        <div class="column">
            <div class="pagination-info">
            {% blocktrans with start=page_obj.start_index end=page_obj.end_index count=paginator.count %}
                {{ start }} to {{ end }} of {{ count }} entries
            {% endblocktrans %}
            </div>
        </div>
    </div>
{% endif %}
