{% load widget_tweaks %}
    {% if field|widget_type == 'checkboxinput' or field|widget_type == 'radioselect'%}
            <div class="row">
                <div class="{% if size %}small-{{size}}{% else %}small-2{% endif %} columns">
                    {% include "arctic/partials/form_field_parts/field_label.html" %}
                </div>
                <div class="{% if size %}small{{-12|add:size}}{% else %}small-10{% endif %} columns">
                    <label for="{{ field.auto_id }}">
                        {% include "arctic/partials/form_field_parts/render_field.html" %}
                    </label>
                </div>
            </div>
    {% else %}
        <div class="row">
            <div class="{% if size %}small-{{size}}{% else %}small-2{% endif %} columns">
                <label for="{{ field.auto_id }}" class="{% if field.field.required %}required{% endif %}">
                    {% include "arctic/partials/form_field_parts/field_label.html" %}
                </label>
            </div>
            <div class="{% if size %}small{{-12|add:size}}{% else %}small-10{% endif %} columns">
                {% include "arctic/partials/form_field_parts/checkbox_select_multiple.html" %}
            </div>
        </div>
    {% endif %}

