<div class="columns" data-tree="/categories/navigation-ajax">

    {% comment %}
        deactived search cause business wants to search without lazy.., so through all results and not only visible

        <form class="row" data-tree-search>
            <div class="columns">
                <input type="text" placeholder="Search within visible categories" />
            </div>
            <div class="columns shrink">
                <input type="submit" value="Search" class="button" />
            </div>
        </form>
    {% endcomment %}

    <div data-tree-container></div>
</div>